CVS commit: src/usr.bin/make

2011-05-18 Thread David Laight
Module Name:src
Committed By:   dsl
Date:   Wed May 18 06:36:48 UTC 2011

Modified Files:
src/usr.bin/make: Makefile

Log Message:
Back out a local change


To generate a diff of this commit:
cvs rdiff -u -r1.52 -r1.53 src/usr.bin/make/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/make/Makefile
diff -u src/usr.bin/make/Makefile:1.52 src/usr.bin/make/Makefile:1.53
--- src/usr.bin/make/Makefile:1.52	Tue May 17 21:56:51 2011
+++ src/usr.bin/make/Makefile	Wed May 18 06:36:48 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.52 2011/05/17 21:56:51 dsl Exp $
+#	$NetBSD: Makefile,v 1.53 2011/05/18 06:36:48 dsl Exp $
 #	@(#)Makefile	5.2 (Berkeley) 12/28/90
 
 PROG=	make
@@ -38,7 +38,6 @@
 CPPFLAGS+= -DMAKE_NATIVE
 COPTS.var.c+= -Wno-cast-qual
 
-.if 0
 .ifdef TOOLDIR
 # this is a native netbsd build, 
 # use libutil rather than the local emalloc etc.
@@ -46,7 +45,6 @@
 LDADD+=-lutil
 DPADD+=${LIBUTIL}
 .endif
-.endif
 
 # A simple unit-test driver to help catch regressions
 accept test:



CVS commit: src/sys/arch/hpc/hpc/platid_gen

2011-05-18 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Wed May 18 12:10:23 UTC 2011

Modified Files:
src/sys/arch/hpc/hpc/platid_gen: scan.l

Log Message:
Use option noyywrap.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/hpc/hpc/platid_gen/scan.l

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/hpc/hpc/platid_gen/scan.l
diff -u src/sys/arch/hpc/hpc/platid_gen/scan.l:1.4 src/sys/arch/hpc/hpc/platid_gen/scan.l:1.5
--- src/sys/arch/hpc/hpc/platid_gen/scan.l:1.4	Sun Feb 19 13:06:06 2006
+++ src/sys/arch/hpc/hpc/platid_gen/scan.l	Wed May 18 12:10:22 2011
@@ -1,5 +1,5 @@
 %{
-/*	$NetBSD: scan.l,v 1.4 2006/02/19 13:06:06 peter Exp $	*/
+/*	$NetBSD: scan.l,v 1.5 2011/05/18 12:10:22 nonaka Exp $	*/
 
 /*-
  * Copyright (c) 1999
@@ -43,11 +43,10 @@
 int	yyline;
 char	*getstr(char *);
 void	getcomment(void);
-
-#define	yywrap() 1
-
 %}
 
+%option	noyywrap
+
 %%
 #[^\n]*\n		{ yylval.str = strdup(yytext); yyline++; return DIRECTIVE; }
 \([^]|\\\)*\	{ yylval.str = getstr(yytext); return NAME; }



CVS commit: src/sys/arch/hpc

2011-05-18 Thread NONAKA Kimihiro
Module Name:src
Committed By:   nonaka
Date:   Wed May 18 12:11:46 UTC 2011

Modified Files:
src/sys/arch/hpc/conf: platid.def
src/sys/arch/hpc/hpc: platid_mask.c platid_name.c
src/sys/arch/hpc/include: platid_generated.h platid_mask.h
src/sys/arch/hpc/stand/hpcboot: machine_config.cpp

Log Message:
Added Psion Teklogix NETBOOK PRO entry.


To generate a diff of this commit:
cvs rdiff -u -r1.25 -r1.26 src/sys/arch/hpc/conf/platid.def
cvs rdiff -u -r1.24 -r1.25 src/sys/arch/hpc/hpc/platid_mask.c \
src/sys/arch/hpc/hpc/platid_name.c
cvs rdiff -u -r1.24 -r1.25 src/sys/arch/hpc/include/platid_generated.h \
src/sys/arch/hpc/include/platid_mask.h
cvs rdiff -u -r1.14 -r1.15 src/sys/arch/hpc/stand/hpcboot/machine_config.cpp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/hpc/conf/platid.def
diff -u src/sys/arch/hpc/conf/platid.def:1.25 src/sys/arch/hpc/conf/platid.def:1.26
--- src/sys/arch/hpc/conf/platid.def:1.25	Tue Apr  6 16:15:34 2010
+++ src/sys/arch/hpc/conf/platid.def	Wed May 18 12:11:46 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: platid.def,v 1.25 2010/04/06 16:15:34 nonaka Exp $	*/
+/*	$NetBSD: platid.def,v 1.26 2011/05/18 12:11:46 nonaka Exp $	*/
 
 /*-
  * Copyright (c) 1999-2001
@@ -410,3 +410,12 @@
 	}
 }
 #endif /* hpcmips */
+
+#ifdef hpcarm
+PSIONTEKLOGIX {
+  NETBOOK {
+CPU=ARM_XSCALE_PXA250
+PRO - NETBOOK PRO
+  }
+}
+#endif /* hpcarm */

Index: src/sys/arch/hpc/hpc/platid_mask.c
diff -u src/sys/arch/hpc/hpc/platid_mask.c:1.24 src/sys/arch/hpc/hpc/platid_mask.c:1.25
--- src/sys/arch/hpc/hpc/platid_mask.c:1.24	Tue Apr  6 16:18:24 2010
+++ src/sys/arch/hpc/hpc/platid_mask.c	Wed May 18 12:11:46 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: platid_mask.c,v 1.24 2010/04/06 16:18:24 nonaka Exp $	*/
+/*	$NetBSD: platid_mask.c,v 1.25 2011/05/18 12:11:46 nonaka Exp $	*/
 
 /*-
  * Copyright (c) 1999-2001
@@ -948,3 +948,17 @@
 	PLATID_MACH_AGENDA_VR_VR3
 }};
 #endif /* hpcmips */
+#ifdef hpcarm
+platid_t platid_mask_MACH_PSIONTEKLOGIX = {{
+	PLATID_WILD,
+	PLATID_MACH_PSIONTEKLOGIX
+}};
+platid_t platid_mask_MACH_PSIONTEKLOGIX_NETBOOK = {{
+	PLATID_WILD,
+	PLATID_MACH_PSIONTEKLOGIX_NETBOOK
+}};
+platid_t platid_mask_MACH_PSIONTEKLOGIX_NETBOOK_PRO = {{
+	PLATID_CPU_ARM_XSCALE_PXA250,
+	PLATID_MACH_PSIONTEKLOGIX_NETBOOK_PRO
+}};
+#endif /* hpcarm */
Index: src/sys/arch/hpc/hpc/platid_name.c
diff -u src/sys/arch/hpc/hpc/platid_name.c:1.24 src/sys/arch/hpc/hpc/platid_name.c:1.25
--- src/sys/arch/hpc/hpc/platid_name.c:1.24	Tue Apr  6 16:18:24 2010
+++ src/sys/arch/hpc/hpc/platid_name.c	Wed May 18 12:11:46 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: platid_name.c,v 1.24 2010/04/06 16:18:24 nonaka Exp $	*/
+/*	$NetBSD: platid_name.c,v 1.25 2011/05/18 12:11:46 nonaka Exp $	*/
 
 /*-
  * Copyright (c) 1999-2001
@@ -519,5 +519,13 @@
 	{ platid_mask_MACH_AGENDA_VR_VR3,
 	 TEXT(AGENDA VR3+) },
 #endif /* hpcmips */
+#ifdef hpcarm
+	{ platid_mask_MACH_PSIONTEKLOGIX,
+	 TEXT(PSIONTEKLOGIX) },
+	{ platid_mask_MACH_PSIONTEKLOGIX_NETBOOK,
+	 TEXT(PSIONTEKLOGIX NETBOOK) },
+	{ platid_mask_MACH_PSIONTEKLOGIX_NETBOOK_PRO,
+	 TEXT(PSIONTEKLOGIX NETBOOK PRO) },
+#endif /* hpcarm */
 };
 int platid_name_table_size = sizeof(platid_name_table)/sizeof(*platid_name_table);

Index: src/sys/arch/hpc/include/platid_generated.h
diff -u src/sys/arch/hpc/include/platid_generated.h:1.24 src/sys/arch/hpc/include/platid_generated.h:1.25
--- src/sys/arch/hpc/include/platid_generated.h:1.24	Tue Apr  6 16:23:17 2010
+++ src/sys/arch/hpc/include/platid_generated.h	Wed May 18 12:11:46 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: platid_generated.h,v 1.24 2010/04/06 16:23:17 nonaka Exp $	*/
+/*	$NetBSD: platid_generated.h,v 1.25 2011/05/18 12:11:46 nonaka Exp $	*/
 
 /*-
  * Copyright (c) 1999-2001
@@ -1480,3 +1480,25 @@
   ((PLATID_MACH_AGENDA_VR_VR3_NUM  PLATID_MODEL_SHIFT)| \
 PLATID_MACH_AGENDA_VR)
 #endif /* hpcmips */
+#ifdef hpcarm
+#ifndef SPEC_PLATFORM
+#define SPEC_MACH_PSIONTEKLOGIX
+#endif /* !SPEC_PLATFORM */
+#define PLATID_MACH_PSIONTEKLOGIX_NUM	16
+#define PLATID_MACH_PSIONTEKLOGIX	\
+  ((PLATID_MACH_PSIONTEKLOGIX_NUM  PLATID_VENDOR_SHIFT))
+#ifndef SPEC_PLATFORM
+#define SPEC_MACH_PSIONTEKLOGIX_NETBOOK
+#endif /* !SPEC_PLATFORM */
+#define PLATID_MACH_PSIONTEKLOGIX_NETBOOK_NUM	1
+#define PLATID_MACH_PSIONTEKLOGIX_NETBOOK	\
+  ((PLATID_MACH_PSIONTEKLOGIX_NETBOOK_NUM  PLATID_SERIES_SHIFT)| \
+PLATID_MACH_PSIONTEKLOGIX)
+#ifndef SPEC_PLATFORM
+#define SPEC_MACH_PSIONTEKLOGIX_NETBOOK_PRO
+#endif /* !SPEC_PLATFORM */
+#define PLATID_MACH_PSIONTEKLOGIX_NETBOOK_PRO_NUM	1
+#define PLATID_MACH_PSIONTEKLOGIX_NETBOOK_PRO	\
+  ((PLATID_MACH_PSIONTEKLOGIX_NETBOOK_PRO_NUM  PLATID_MODEL_SHIFT)| \
+PLATID_MACH_PSIONTEKLOGIX_NETBOOK)
+#endif /* hpcarm */
Index: src/sys/arch/hpc/include/platid_mask.h
diff -u src/sys/arch/hpc/include/platid_mask.h:1.24 src/sys/arch/hpc/include/platid_mask.h:1.25
--- 

CVS commit: src/sys/arch/x86

2011-05-18 Thread Matthias Drochner
Module Name:src
Committed By:   drochner
Date:   Wed May 18 12:53:04 UTC 2011

Modified Files:
src/sys/arch/x86/include: i82489var.h
src/sys/arch/x86/x86: lapic.c

Log Message:
remove stale declarations / empty function


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/sys/arch/x86/include/i82489var.h
cvs rdiff -u -r1.44 -r1.45 src/sys/arch/x86/x86/lapic.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x86/include/i82489var.h
diff -u src/sys/arch/x86/include/i82489var.h:1.12 src/sys/arch/x86/include/i82489var.h:1.13
--- src/sys/arch/x86/include/i82489var.h:1.12	Mon Apr 28 20:23:40 2008
+++ src/sys/arch/x86/include/i82489var.h	Wed May 18 12:53:04 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: i82489var.h,v 1.12 2008/04/28 20:23:40 martin Exp $	*/
+/*	$NetBSD: i82489var.h,v 1.13 2011/05/18 12:53:04 drochner Exp $	*/
 
 /*-
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -112,8 +112,6 @@
 extern void lapic_boot_init(paddr_t);
 extern void lapic_set_lvt(void);
 extern void lapic_enable(void);
-extern void lapic_suspend(void);
-extern void lapic_resume(void);
 extern void lapic_calibrate_timer(struct cpu_info *ci);
 extern void lapic_initclocks(void);
 

Index: src/sys/arch/x86/x86/lapic.c
diff -u src/sys/arch/x86/x86/lapic.c:1.44 src/sys/arch/x86/x86/lapic.c:1.45
--- src/sys/arch/x86/x86/lapic.c:1.44	Sat Nov 21 03:11:01 2009
+++ src/sys/arch/x86/x86/lapic.c	Wed May 18 12:53:04 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: lapic.c,v 1.44 2009/11/21 03:11:01 rmind Exp $	*/
+/*	$NetBSD: lapic.c,v 1.45 2011/05/18 12:53:04 drochner Exp $	*/
 
 /*-
  * Copyright (c) 2000, 2008 The NetBSD Foundation, Inc.
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: lapic.c,v 1.44 2009/11/21 03:11:01 rmind Exp $);
+__KERNEL_RCSID(0, $NetBSD: lapic.c,v 1.45 2011/05/18 12:53:04 drochner Exp $);
 
 #include opt_ddb.h
 #include opt_mpbios.h		/* for MPDEBUG */
@@ -144,11 +144,6 @@
 }
 
 void
-lapic_suspend(void)
-{
-}
-
-void
 lapic_set_lvt(void)
 {
 	struct cpu_info *ci = curcpu();



CVS commit: src/sys/dist/pf/net

2011-05-18 Thread Matthias Drochner
Module Name:src
Committed By:   drochner
Date:   Wed May 18 12:54:15 UTC 2011

Modified Files:
src/sys/dist/pf/net: pf_osfp.c

Log Message:
remove unused expression


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/sys/dist/pf/net/pf_osfp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dist/pf/net/pf_osfp.c
diff -u src/sys/dist/pf/net/pf_osfp.c:1.10 src/sys/dist/pf/net/pf_osfp.c:1.11
--- src/sys/dist/pf/net/pf_osfp.c:1.10	Mon Apr 12 13:57:38 2010
+++ src/sys/dist/pf/net/pf_osfp.c	Wed May 18 12:54:15 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: pf_osfp.c,v 1.10 2010/04/12 13:57:38 ahoka Exp $	*/
+/*	$NetBSD: pf_osfp.c,v 1.11 2011/05/18 12:54:15 drochner Exp $	*/
 /*	$OpenBSD: pf_osfp.c,v 1.12 2006/12/13 18:14:10 itojun Exp $ */
 
 /*
@@ -19,7 +19,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: pf_osfp.c,v 1.10 2010/04/12 13:57:38 ahoka Exp $);
+__KERNEL_RCSID(0, $NetBSD: pf_osfp.c,v 1.11 2011/05/18 12:54:15 drochner Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_inet.h
@@ -585,7 +585,7 @@
 		if (find.fp_mss == 0)
 			find.fp_mss = 128;
 		if (f-fp_flags  PF_OSFP_WSIZE_MSS)
-			find.fp_wsize *= find.fp_mss, 1;
+			find.fp_wsize *= find.fp_mss;
 		else if (f-fp_flags  PF_OSFP_WSIZE_MTU)
 			find.fp_wsize *= (find.fp_mss + 40);
 		else if (f-fp_flags  PF_OSFP_WSIZE_MOD)



CVS commit: src/share/mk

2011-05-18 Thread Adam Ciarcinski
Module Name:src
Committed By:   adam
Date:   Wed May 18 13:08:14 UTC 2011

Modified Files:
src/share/mk: bsd.own.mk

Log Message:
Add support for LLVM/Clang


To generate a diff of this commit:
cvs rdiff -u -r1.664 -r1.665 src/share/mk/bsd.own.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/mk/bsd.own.mk
diff -u src/share/mk/bsd.own.mk:1.664 src/share/mk/bsd.own.mk:1.665
--- src/share/mk/bsd.own.mk:1.664	Mon May  9 14:36:48 2011
+++ src/share/mk/bsd.own.mk	Wed May 18 13:08:14 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: bsd.own.mk,v 1.664 2011/05/09 14:36:48 haad Exp $
+#	$NetBSD: bsd.own.mk,v 1.665 2011/05/18 13:08:14 adam Exp $
 
 # This needs to be before bsd.init.mk
 .if defined(BSD_MK_COMPAT_FILE)
@@ -47,7 +47,7 @@
 TOOLCHAIN_MISSING?=	no
 
 # default to GCC4
-.if !defined(HAVE_GCC)  !defined(HAVE_PCC)
+.if !defined(HAVE_GCC)  !defined(HAVE_PCC)  !defined(HAVE_LLVM)
 HAVE_GCC=	4
 .endif
 
@@ -207,6 +207,14 @@
 OBJC=		false
 .endif
 
+.if defined(HAVE_LLVM)  ${USETOOLS_LLVM:Uyes} == yes
+CC=		${TOOLDIR}/bin/${MACHINE_GNU_PLATFORM}-clang
+CPP=		${TOOLDIR}/bin/${MACHINE_GNU_PLATFORM}-clang-cpp
+CXX=		${TOOLDIR}/bin/${MACHINE_GNU_PLATFORM}-clang++
+FC=		false
+OBJC=		${TOOLDIR}/bin/${MACHINE_GNU_PLATFORM}-clang
+.endif
+
 #
 # Make sure DESTDIR is set, so that builds with these tools always
 # get appropriate -nostdinc, -nostdlib, etc. handling.  The default is



CVS commit: src/sys/kern

2011-05-18 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Wed May 18 14:48:04 UTC 2011

Modified Files:
src/sys/kern: sys_select.c

Log Message:
No need to mask twice. The setup function does it.


To generate a diff of this commit:
cvs rdiff -u -r1.31 -r1.32 src/sys/kern/sys_select.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/sys_select.c
diff -u src/sys/kern/sys_select.c:1.31 src/sys/kern/sys_select.c:1.32
--- src/sys/kern/sys_select.c:1.31	Tue May 17 23:51:41 2011
+++ src/sys/kern/sys_select.c	Wed May 18 10:48:04 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: sys_select.c,v 1.31 2011/05/18 03:51:41 christos Exp $	*/
+/*	$NetBSD: sys_select.c,v 1.32 2011/05/18 14:48:04 christos Exp $	*/
 
 /*-
  * Copyright (c) 2007, 2008, 2009, 2010 The NetBSD Foundation, Inc.
@@ -84,7 +84,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: sys_select.c,v 1.31 2011/05/18 03:51:41 christos Exp $);
+__KERNEL_RCSID(0, $NetBSD: sys_select.c,v 1.32 2011/05/18 14:48:04 christos Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -229,10 +229,8 @@
 		return EINVAL;
 	}
 
-	if (__predict_false(mask)) {
-		sigminusset(sigcantmask, mask);
+	if (__predict_false(mask))
 		sigsuspendsetup(l, mask);
-	}
 
 	sc = curcpu()-ci_data.cpu_selcluster;
 	lock = sc-sc_lock;



CVS commit: src/lib/libperfuse

2011-05-18 Thread Emmanuel Dreyfus
Module Name:src
Committed By:   manu
Date:   Wed May 18 15:22:54 UTC 2011

Modified Files:
src/lib/libperfuse: perfuse_if.h

Log Message:
typos


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.12 src/lib/libperfuse/perfuse_if.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libperfuse/perfuse_if.h
diff -u src/lib/libperfuse/perfuse_if.h:1.11 src/lib/libperfuse/perfuse_if.h:1.12
--- src/lib/libperfuse/perfuse_if.h:1.11	Wed May 11 14:52:48 2011
+++ src/lib/libperfuse/perfuse_if.h	Wed May 18 15:22:54 2011
@@ -1,7 +1,7 @@
-/*  $NetBSD: perfuse_if.h,v 1.11 2011/05/11 14:52:48 jakllsch Exp $ */
+/*  $NetBSD: perfuse_if.h,v 1.12 2011/05/18 15:22:54 manu Exp $ */
 
 /*-
- *  Copyright (c) 2010 Emmanuel Dreyfus. All rights reserved.
+ *  Copyright (c) 2010-2011 Emmanuel Dreyfus. All rights reserved.
  * 
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -25,8 +25,8 @@
  *  POSSIBILITY OF SUCH DAMAGE.
  */ 
 
-#ifndef _REFUSE_PERFUSE_H
-#define _REFUSE_PERFUSE_H
+#ifndef _PERFUSE_IF_H
+#define _PERFUSE_IF_H
 
 #ifndef _PATH_PERFUSED
 #define _PATH_PERFUSED /usr/sbin/perfused
@@ -171,7 +171,7 @@
 };
 
 /*
- * Duplicated fro fuse.h to avoid making it public
+ * Duplicated from fuse.h to avoid making it public
  */
 #ifndef FUSE_BUFSIZE
 #define FUSE_MIN_BUFSIZE 0x21000
@@ -210,4 +210,4 @@
 int perfuse_mainloop(struct puffs_usermount *);
 int perfuse_unmount(struct puffs_usermount *);
 
-#endif /* _REFUSE_PERFUSE_H */
+#endif /* _PERFUSE_IF_H */



CVS commit: src/lib/libperfuse

2011-05-18 Thread Emmanuel Dreyfus
Module Name:src
Committed By:   manu
Date:   Wed May 18 15:25:19 UTC 2011

Modified Files:
src/lib/libperfuse: perfuse.c

Log Message:
Set buffer size as big in nomal mode as we do in debug mode, when
perfused stays in foreground. The difference is a mistake and was not
intended.

There is still a bug ready to bite here, since SOCK_STREAM is not reliable.
We just hope that buffers are big enough to hold all packets, but if they
are overflown, we loose a packet and a file operation gets stuck.

We really nee SOCk_SEQPACKET here, but unfortunately it is very broken at
that time.


To generate a diff of this commit:
cvs rdiff -u -r1.13 -r1.14 src/lib/libperfuse/perfuse.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libperfuse/perfuse.c
diff -u src/lib/libperfuse/perfuse.c:1.13 src/lib/libperfuse/perfuse.c:1.14
--- src/lib/libperfuse/perfuse.c:1.13	Thu May 12 10:32:41 2011
+++ src/lib/libperfuse/perfuse.c	Wed May 18 15:25:19 2011
@@ -1,4 +1,4 @@
-/*  $NetBSD: perfuse.c,v 1.13 2011/05/12 10:32:41 manu Exp $ */
+/*  $NetBSD: perfuse.c,v 1.14 2011/05/18 15:25:19 manu Exp $ */
 
 /*-
  *  Copyright (c) 2010-2011 Emmanuel Dreyfus. All rights reserved.
@@ -197,22 +197,22 @@
 	 * Set a buffer lentgh large enough so that any FUSE packet
 	 * will fit.
 	 */
-	opt = FUSE_BUFSIZE;
+	opt = 4 * FUSE_BUFSIZE;
 	optlen = sizeof(opt);
 	if (setsockopt(sv[0], SOL_SOCKET, SO_SNDBUF, opt, optlen) != 0)
 		DWARN(%s: setsockopt SO_SNDBUF to %d failed, __func__, opt);
 
-	opt = FUSE_BUFSIZE;
+	opt = 4 * FUSE_BUFSIZE;
 	optlen = sizeof(opt);
 	if (setsockopt(sv[0], SOL_SOCKET, SO_RCVBUF, opt, optlen) != 0)
 		DWARN(%s: setsockopt SO_RCVBUF to %d failed, __func__, opt);
 
-	opt = FUSE_BUFSIZE;
+	opt = 4 * FUSE_BUFSIZE;
 	optlen = sizeof(opt);
 	if (setsockopt(sv[1], SOL_SOCKET, SO_SNDBUF, opt, optlen) != 0)
 		DWARN(%s: setsockopt SO_SNDBUF to %d failed, __func__, opt);
 
-	opt = FUSE_BUFSIZE;
+	opt = 4 * FUSE_BUFSIZE;
 	optlen = sizeof(opt);
 	if (setsockopt(sv[1], SOL_SOCKET, SO_RCVBUF, opt, optlen) != 0)
 		DWARN(%s: setsockopt SO_RCVBUF to %d failed, __func__, opt);



CVS commit: src/lib/libperfuse

2011-05-18 Thread Emmanuel Dreyfus
Module Name:src
Committed By:   manu
Date:   Wed May 18 15:28:12 UTC 2011

Modified Files:
src/lib/libperfuse: ops.c

Log Message:
- Proper permission checks when doing directory traversal. e.g.: run
rm dir/file while dir was never looked up since the mount. In that
situation, we get lookup with pcn_nameiop NAMEI_DELETE for dir before
we get it for file. But for dir we are just looking for PUFFS_VEXEC.
This is solved by honouring NAMEI_ISLASTCN, which is set for the last
element only

- do not send O_EXCL to FUSE as documentation forbids it.

- fix warning


To generate a diff of this commit:
cvs rdiff -u -r1.26 -r1.27 src/lib/libperfuse/ops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/rump/librump/rumpkern/signals.c
diff -u src/sys/rump/librump/rumpkern/signals.c:1.8 src/sys/rump/librump/rumpkern/signals.c:1.9
--- src/sys/rump/librump/rumpkern/signals.c:1.8	Sun Feb 20 08:09:57 2011
+++ src/sys/rump/librump/rumpkern/signals.c	Wed May 18 11:57:14 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: signals.c,v 1.8 2011/02/20 13:09:57 pooka Exp $	*/
+/*	$NetBSD: signals.c,v 1.9 2011/05/18 15:57:14 christos Exp $	*/
 
 /*-
  * Copyright (c) 2010, 2011 Antti Kantee.  All Rights Reserved.
@@ -26,7 +26,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: signals.c,v 1.8 2011/02/20 13:09:57 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: signals.c,v 1.9 2011/05/18 15:57:14 christos Exp $);
 
 #include sys/param.h
 #include sys/atomic.h
@@ -276,3 +276,17 @@
 	sigemptyset(p-p_sigctx.ps_sigignore);
 	sigemptyset(p-p_sigpend.sp_set);
 }
+
+void
+sigsuspendsetup(struct lwp *l, const sigset_t *ss)
+{
+	/* XXX: Partial copy of kernel code, remove and use the kernel code */
+	struct proc *p = l-l_proc;
+
+	mutex_enter(p-p_lock);
+	l-l_sigrestore = 1;
+	l-l_sigoldmask = l-l_sigmask;
+	l-l_sigmask = *ss;
+	sigminusset(sigcantmask, l-l_sigmask);
+	mutex_exit(p-p_lock);
+}



CVS commit: src/sys/netipsec

2011-05-18 Thread Matthias Drochner
Module Name:src
Committed By:   drochner
Date:   Wed May 18 18:36:16 UTC 2011

Modified Files:
src/sys/netipsec: key.c

Log Message:
use monotonic time rather than wall time for lifetime related timestamps,
to make key expiration robust against time changes


To generate a diff of this commit:
cvs rdiff -u -r1.68 -r1.69 src/sys/netipsec/key.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/netipsec/key.c
diff -u src/sys/netipsec/key.c:1.68 src/sys/netipsec/key.c:1.69
--- src/sys/netipsec/key.c:1.68	Tue May 17 18:57:02 2011
+++ src/sys/netipsec/key.c	Wed May 18 18:36:15 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: key.c,v 1.68 2011/05/17 18:57:02 drochner Exp $	*/
+/*	$NetBSD: key.c,v 1.69 2011/05/18 18:36:15 drochner Exp $	*/
 /*	$FreeBSD: src/sys/netipsec/key.c,v 1.3.2.3 2004/02/14 22:23:23 bms Exp $	*/
 /*	$KAME: key.c,v 1.191 2001/06/27 10:46:49 sakane Exp $	*/
 	
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: key.c,v 1.68 2011/05/17 18:57:02 drochner Exp $);
+__KERNEL_RCSID(0, $NetBSD: key.c,v 1.69 2011/05/18 18:36:15 drochner Exp $);
 
 /*
  * This code is referd to RFC 2367
@@ -631,7 +631,7 @@
 		KEY_CHKSPDIR(sp-spidx.dir, dir, key_allocsp);
 
 		/* found a SPD entry */
-		sp-lastused = time_second;
+		sp-lastused = time_uptime;
 		SP_ADDREF(sp);
 	}
 	splx(s);
@@ -695,7 +695,7 @@
 		KEY_CHKSPDIR(sp-spidx.dir, dir, key_allocsp2);
 
 		/* found a SPD entry */
-		sp-lastused = time_second;
+		sp-lastused = time_uptime;
 		SP_ADDREF(sp);
 	}
 	splx(s);
@@ -772,7 +772,7 @@
 	sp = NULL;
 found:
 	if (sp) {
-		sp-lastused = time_second;
+		sp-lastused = time_uptime;
 		SP_ADDREF(sp);
 	}
 	splx(s);
@@ -1961,7 +1961,7 @@
 	}
 #endif
 
-	newsp-created = time_second;
+	newsp-created = time_uptime;
 	newsp-lastused = newsp-created;
 	newsp-lifetime = lft ? lft-sadb_lifetime_addtime : 0;
 	newsp-validtime = lft ? lft-sadb_lifetime_usetime : 0;
@@ -1975,7 +1975,7 @@
 		struct secspacq *spacq;
 		if ((spacq = key_getspacq(spidx)) != NULL) {
 			/* reset counter in order to deletion by timehandler. */
-			spacq-created = time_second;
+			spacq-created = time_uptime;
 			spacq-count = 0;
 		}
 	}
@@ -2793,8 +2793,8 @@
 	lt-sadb_lifetime_exttype = SADB_EXT_LIFETIME_CURRENT;
 	lt-sadb_lifetime_allocations = 0;
 	lt-sadb_lifetime_bytes = 0;
-	lt-sadb_lifetime_addtime = sp-created;
-	lt-sadb_lifetime_usetime = sp-lastused;
+	lt-sadb_lifetime_addtime = sp-created + time_second - time_uptime;
+	lt-sadb_lifetime_usetime = sp-lastused + time_second - time_uptime;
 	lt = (struct sadb_lifetime *)(mtod(m, char *) + len / 2);
 	lt-sadb_lifetime_len = PFKEY_UNIT64(sizeof(struct sadb_lifetime));
 	lt-sadb_lifetime_exttype = SADB_EXT_LIFETIME_HARD;
@@ -3021,7 +3021,7 @@
 	}
 
 	/* reset created */
-	newsav-created = time_second;
+	newsav-created = time_uptime;
 	newsav-pid = mhp-msg-sadb_msg_pid;
 
 	/* add to satree */
@@ -3366,7 +3366,7 @@
 	}
 
 	/* reset created */
-	sav-created = time_second;
+	sav-created = time_uptime;
 
 	/* make lifetime for CURRENT */
 	KMALLOC(sav-lft_c, struct sadb_lifetime *,
@@ -3382,7 +3382,7 @@
 	sav-lft_c-sadb_lifetime_exttype = SADB_EXT_LIFETIME_CURRENT;
 	sav-lft_c-sadb_lifetime_allocations = 0;
 	sav-lft_c-sadb_lifetime_bytes = 0;
-	sav-lft_c-sadb_lifetime_addtime = time_second;
+	sav-lft_c-sadb_lifetime_addtime = time_uptime;
 	sav-lft_c-sadb_lifetime_usetime = 0;
 
 	/* lifetimes for HARD and SOFT */
@@ -3553,6 +3553,7 @@
 	int l = 0;
 	int i;
 	void *p;
+	struct sadb_lifetime lt;
 	int dumporder[] = {
 		SADB_EXT_SA, SADB_X_EXT_SA2,
 		SADB_EXT_LIFETIME_HARD, SADB_EXT_LIFETIME_SOFT,
@@ -3618,7 +3619,10 @@
 			if (!sav-lft_c)
 continue;
 			l = PFKEY_UNUNIT64(((struct sadb_ext *)sav-lft_c)-sadb_ext_len);
-			p = sav-lft_c;
+			memcpy(lt, sav-lft_c, sizeof(struct sadb_lifetime));
+			lt.sadb_lifetime_addtime += time_second - time_uptime;
+			lt.sadb_lifetime_usetime += time_second - time_uptime;
+			p = lt;
 			break;
 
 		case SADB_EXT_LIFETIME_HARD:
@@ -4510,7 +4514,7 @@
 {
 	u_int dir;
 	int s;
-	time_t now = time_second;
+	time_t now = time_uptime;
 
 	s = splsoftnet();	/*called from softclock()*/
 	mutex_enter(softnet_lock);
@@ -4992,7 +4996,7 @@
 		struct secacq *acq;
 		if ((acq = key_getacqbyseq(mhp-msg-sadb_msg_seq)) != NULL) {
 			/* reset counter in order to deletion by timehandler. */
-			acq-created = time_second;
+			acq-created = time_uptime;
 			acq-count = 0;
 		}
 	}
@@ -6476,7 +6480,7 @@
 	/* copy secindex */
 	memcpy(newacq-saidx, saidx, sizeof(newacq-saidx));
 	newacq-seq = (acq_seq == ~0 ? 1 : ++acq_seq);
-	newacq-created = time_second;
+	newacq-created = time_uptime;
 	newacq-count = 0;
 
 	return newacq;
@@ -6524,7 +6528,7 @@
 
 	/* copy secindex */
 	memcpy(acq-spidx, spidx, sizeof(acq-spidx));
-	acq-created = time_second;
+	acq-created = time_uptime;
 	acq-count = 0;
 
 	return acq;
@@ -6598,7 +6602,7 @@
 		}
 
 		/* reset 

CVS commit: src/regress/sys/arch/m68k/emuspeed

2011-05-18 Thread Izumi Tsutsui
Module Name:src
Committed By:   tsutsui
Date:   Wed May 18 18:41:59 UTC 2011

Modified Files:
src/regress/sys/arch/m68k/emuspeed: emuspeed.c

Log Message:
WARNSfy


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/regress/sys/arch/m68k/emuspeed/emuspeed.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/regress/sys/arch/m68k/emuspeed/emuspeed.c
diff -u src/regress/sys/arch/m68k/emuspeed/emuspeed.c:1.7 src/regress/sys/arch/m68k/emuspeed/emuspeed.c:1.8
--- src/regress/sys/arch/m68k/emuspeed/emuspeed.c:1.7	Mon Apr 28 20:23:06 2008
+++ src/regress/sys/arch/m68k/emuspeed/emuspeed.c	Wed May 18 18:41:59 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: emuspeed.c,v 1.7 2008/04/28 20:23:06 martin Exp $	*/
+/*	$NetBSD: emuspeed.c,v 1.8 2011/05/18 18:41:59 tsutsui Exp $	*/
 
 /*-
  * Copyright (c) 1997 The NetBSD Foundation, Inc.
@@ -26,6 +26,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include err.h
 #include setjmp.h
 #include signal.h
 #include stdlib.h
@@ -38,9 +39,9 @@
 #define PRECISION 500
 
 const struct test {
-	char *name; 
+	const char *name; 
 	void (*func)(int);
-	char *comment;
+	const char *comment;
 } testlist[] = {
 	{Illegal, illegal, (test: unimplemented)},
 	{mulsl Da,Db, mul32sreg, (test: should be native)},
@@ -61,6 +62,7 @@
 
 jmp_buf jbuf;
 void illhand (int);
+int main(int, char *[]);
 
 int
 main(argc, argv)
@@ -94,7 +96,7 @@
 			t-func(count);
 			stop = clock();
 		} while ((stop - start)  PRECISION);
-		printf(%10d/s%s\n,
+		printf(%10lu/s%s\n,
 		CLOCKS_PER_SEC*(count /(stop - start)),
 		t-comment);
 	}



CVS commit: src/sys/netipsec

2011-05-18 Thread Matthias Drochner
Module Name:src
Committed By:   drochner
Date:   Wed May 18 18:56:02 UTC 2011

Modified Files:
src/sys/netipsec: key.c

Log Message:
include the SHA2 hashs into the proposal which goes out with
SADB_ACQUIRE -- this doesn't change much because racoon ignores
the proposal from the kernel anyway and applies its own configuration,
but having MD5 and SHA1 in the list but SHA2 not looks strange


To generate a diff of this commit:
cvs rdiff -u -r1.69 -r1.70 src/sys/netipsec/key.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/netipsec/key.c
diff -u src/sys/netipsec/key.c:1.69 src/sys/netipsec/key.c:1.70
--- src/sys/netipsec/key.c:1.69	Wed May 18 18:36:15 2011
+++ src/sys/netipsec/key.c	Wed May 18 18:56:02 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: key.c,v 1.69 2011/05/18 18:36:15 drochner Exp $	*/
+/*	$NetBSD: key.c,v 1.70 2011/05/18 18:56:02 drochner Exp $	*/
 /*	$FreeBSD: src/sys/netipsec/key.c,v 1.3.2.3 2004/02/14 22:23:23 bms Exp $	*/
 /*	$KAME: key.c,v 1.191 2001/06/27 10:46:49 sakane Exp $	*/
 	
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: key.c,v 1.69 2011/05/18 18:36:15 drochner Exp $);
+__KERNEL_RCSID(0, $NetBSD: key.c,v 1.70 2011/05/18 18:56:02 drochner Exp $);
 
 /*
  * This code is referd to RFC 2367
@@ -6138,7 +6138,11 @@
 	for (i = 1; i = SADB_AALG_MAX; i++) {
 #if 1
 		/* we prefer HMAC algorithms, not old algorithms */
-		if (i != SADB_AALG_SHA1HMAC  i != SADB_AALG_MD5HMAC)
+		if (i != SADB_AALG_SHA1HMAC 
+		i != SADB_AALG_MD5HMAC 
+		i != SADB_X_AALG_SHA2_256 
+		i != SADB_X_AALG_SHA2_384 
+		i != SADB_X_AALG_SHA2_512)
 			continue;
 #endif
 		algo = ah_algorithm_lookup(i);



CVS commit: othersrc/external/bsd/genraidconf

2011-05-18 Thread Alistair G. Crooks
Module Name:othersrc
Committed By:   agc
Date:   Wed May 18 19:17:21 UTC 2011

Modified Files:
othersrc/external/bsd/genraidconf: genraidconf.sh

Log Message:
unconfigure the generated raid set at the end of this utility


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 othersrc/external/bsd/genraidconf/genraidconf.sh

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: othersrc/external/bsd/genraidconf/genraidconf.sh
diff -u othersrc/external/bsd/genraidconf/genraidconf.sh:1.3 othersrc/external/bsd/genraidconf/genraidconf.sh:1.4
--- othersrc/external/bsd/genraidconf/genraidconf.sh:1.3	Wed May 18 01:41:31 2011
+++ othersrc/external/bsd/genraidconf/genraidconf.sh	Wed May 18 19:17:21 2011
@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# $NetBSD: genraidconf.sh,v 1.3 2011/05/18 01:41:31 agc Exp $
+# $NetBSD: genraidconf.sh,v 1.4 2011/05/18 19:17:21 agc Exp $
 
 # Copyright (c) 2011 Alistair Crooks a...@netbsd.org
 # All rights reserved.
@@ -253,4 +253,7 @@
 	${doit} raidctl -A root ${raiddev}
 fi
 
+# unconfigure the raid device
+${doit} raidctl -u ${raiddev}
+
 exit 0



CVS commit: src/lib/libc/stdlib

2011-05-18 Thread David Laight
Module Name:src
Committed By:   dsl
Date:   Wed May 18 19:36:36 UTC 2011

Modified Files:
src/lib/libc/stdlib: abort.c exit.c lsearch.c merge.c qsort.c rand48.h
tdelete.c tfind.c tsearch.c twalk.c

Log Message:
Remove __P()


To generate a diff of this commit:
cvs rdiff -u -r1.13 -r1.14 src/lib/libc/stdlib/abort.c
cvs rdiff -u -r1.14 -r1.15 src/lib/libc/stdlib/exit.c
cvs rdiff -u -r1.4 -r1.5 src/lib/libc/stdlib/lsearch.c \
src/lib/libc/stdlib/tdelete.c
cvs rdiff -u -r1.12 -r1.13 src/lib/libc/stdlib/merge.c
cvs rdiff -u -r1.20 -r1.21 src/lib/libc/stdlib/qsort.c
cvs rdiff -u -r1.5 -r1.6 src/lib/libc/stdlib/rand48.h \
src/lib/libc/stdlib/tfind.c src/lib/libc/stdlib/tsearch.c
cvs rdiff -u -r1.2 -r1.3 src/lib/libc/stdlib/twalk.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/stdlib/abort.c
diff -u src/lib/libc/stdlib/abort.c:1.13 src/lib/libc/stdlib/abort.c:1.14
--- src/lib/libc/stdlib/abort.c:1.13	Fri Jan 30 23:21:03 2009
+++ src/lib/libc/stdlib/abort.c	Wed May 18 19:36:36 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: abort.c,v 1.13 2009/01/30 23:21:03 ad Exp $	*/
+/*	$NetBSD: abort.c,v 1.14 2011/05/18 19:36:36 dsl Exp $	*/
 
 /*
  * Copyright (c) 1985, 1993
@@ -34,7 +34,7 @@
 #if 0
 static char sccsid[] = @(#)abort.c	8.1 (Berkeley) 6/4/93;
 #else
-__RCSID($NetBSD: abort.c,v 1.13 2009/01/30 23:21:03 ad Exp $);
+__RCSID($NetBSD: abort.c,v 1.14 2011/05/18 19:36:36 dsl Exp $);
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -43,7 +43,7 @@
 #include stdlib.h
 #include unistd.h
 
-extern void (*__cleanup) __P((void));
+extern void (*__cleanup)(void);
 static int aborting = 0;
 
 void

Index: src/lib/libc/stdlib/exit.c
diff -u src/lib/libc/stdlib/exit.c:1.14 src/lib/libc/stdlib/exit.c:1.15
--- src/lib/libc/stdlib/exit.c:1.14	Mon Mar  7 05:09:12 2011
+++ src/lib/libc/stdlib/exit.c	Wed May 18 19:36:36 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: exit.c,v 1.14 2011/03/07 05:09:12 joerg Exp $	*/
+/*	$NetBSD: exit.c,v 1.15 2011/05/18 19:36:36 dsl Exp $	*/
 
 /*-
  * Copyright (c) 1990, 1993
@@ -34,7 +34,7 @@
 #if 0
 static char sccsid[] = @(#)exit.c	8.1 (Berkeley) 6/4/93;
 #else
-__RCSID($NetBSD: exit.c,v 1.14 2011/03/07 05:09:12 joerg Exp $);
+__RCSID($NetBSD: exit.c,v 1.15 2011/05/18 19:36:36 dsl Exp $);
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -45,7 +45,7 @@
 #include atexit.h
 #endif
 
-void (*__cleanup) __P((void));
+void (*__cleanup)(void);
 
 /*
  * Exit, flushing stdio buffers if necessary.

Index: src/lib/libc/stdlib/lsearch.c
diff -u src/lib/libc/stdlib/lsearch.c:1.4 src/lib/libc/stdlib/lsearch.c:1.5
--- src/lib/libc/stdlib/lsearch.c:1.4	Sat Jul 16 17:32:09 2005
+++ src/lib/libc/stdlib/lsearch.c	Wed May 18 19:36:36 2011
@@ -35,7 +35,7 @@
 #if 0
 static char sccsid[] = @(#)lsearch.c	8.1 (Berkeley) 6/4/93;
 #else
-__RCSID($NetBSD: lsearch.c,v 1.4 2005/07/16 17:32:09 christos Exp $);
+__RCSID($NetBSD: lsearch.c,v 1.5 2011/05/18 19:36:36 dsl Exp $);
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -46,9 +46,9 @@
 #include string.h
 #include search.h
 
-typedef int (*cmp_fn_t) __P((const void *, const void *));
-static void *linear_base __P((const void *, void *, size_t *, size_t,
-			 cmp_fn_t, int));
+typedef int (*cmp_fn_t)(const void *, const void *);
+static void *linear_base(const void *, void *, size_t *, size_t,
+			 cmp_fn_t, int);
 
 void *
 lsearch(key, base, nelp, width, compar)
Index: src/lib/libc/stdlib/tdelete.c
diff -u src/lib/libc/stdlib/tdelete.c:1.4 src/lib/libc/stdlib/tdelete.c:1.5
--- src/lib/libc/stdlib/tdelete.c:1.4	Sun Mar 19 01:12:08 2006
+++ src/lib/libc/stdlib/tdelete.c	Wed May 18 19:36:36 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: tdelete.c,v 1.4 2006/03/19 01:12:08 christos Exp $	*/
+/*	$NetBSD: tdelete.c,v 1.5 2011/05/18 19:36:36 dsl Exp $	*/
 
 /*
  * Tree search generalized from Knuth (6.2.2) Algorithm T just like
@@ -13,7 +13,7 @@
 
 #include sys/cdefs.h
 #if defined(LIBC_SCCS)  !defined(lint)
-__RCSID($NetBSD: tdelete.c,v 1.4 2006/03/19 01:12:08 christos Exp $);
+__RCSID($NetBSD: tdelete.c,v 1.5 2011/05/18 19:36:36 dsl Exp $);
 #endif /* LIBC_SCCS and not lint */
 
 #include assert.h
@@ -27,7 +27,7 @@
 tdelete(vkey, vrootp, compar)
 	const void *vkey;	/* key to be deleted */
 	void  **vrootp;	/* address of the root of tree */
-	int   (*compar) __P((const void *, const void *));
+	int   (*compar)(const void *, const void *);
 {
 	node_t **rootp = (node_t **)vrootp;
 	node_t *p, *q, *r;

Index: src/lib/libc/stdlib/merge.c
diff -u src/lib/libc/stdlib/merge.c:1.12 src/lib/libc/stdlib/merge.c:1.13
--- src/lib/libc/stdlib/merge.c:1.12	Thu Feb 12 03:12:36 2009
+++ src/lib/libc/stdlib/merge.c	Wed May 18 19:36:36 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: merge.c,v 1.12 2009/02/12 03:12:36 lukem Exp $	*/
+/*	$NetBSD: merge.c,v 1.13 2011/05/18 19:36:36 dsl Exp $	*/
 
 /*-
  * Copyright (c) 1992, 1993
@@ -37,7 +37,7 @@
 #if 0
 static char sccsid[] = from: 

CVS commit: xsrc/external/mit/xf86-video-geode/dist/src

2011-05-18 Thread David Laight
Module Name:xsrc
Committed By:   dsl
Date:   Wed May 18 20:50:50 UTC 2011

Modified Files:
xsrc/external/mit/xf86-video-geode/dist/src: geode_msr.c

Log Message:
Add:
#define lseek64 lseek
so this builds.
Has NetBSD ever had an lseek64 - there isn't one in libc - so has this
code ever actually run.


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.1 -r1.2 \
xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c
diff -u xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c:1.1.1.1 xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c:1.2
--- xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c:1.1.1.1	Fri May 28 01:01:12 2010
+++ xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c	Wed May 18 20:50:50 2011
@@ -7,6 +7,8 @@
 #include os.h
 #include geode.h
 
+#define lseek64 lseek
+
 static int
 _msr_open(void)
 {



CVS commit: src/external/mit/xorg/server/drivers/xf86-video-geode

2011-05-18 Thread Iain Hibbert
Module Name:src
Committed By:   plunky
Date:   Wed May 18 20:55:09 UTC 2011

Modified Files:
src/external/mit/xorg/server/drivers/xf86-video-geode: Makefile

Log Message:
add -Dlseek64=lseek to fix the build in geode_msr.c


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 \
src/external/mit/xorg/server/drivers/xf86-video-geode/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/mit/xorg/server/drivers/xf86-video-geode/Makefile
diff -u src/external/mit/xorg/server/drivers/xf86-video-geode/Makefile:1.1 src/external/mit/xorg/server/drivers/xf86-video-geode/Makefile:1.2
--- src/external/mit/xorg/server/drivers/xf86-video-geode/Makefile:1.1	Fri May 28 02:35:46 2010
+++ src/external/mit/xorg/server/drivers/xf86-video-geode/Makefile	Wed May 18 20:55:09 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.1 2010/05/28 02:35:46 mrg Exp $
+#	$NetBSD: Makefile,v 1.2 2011/05/18 20:55:09 plunky Exp $
 
 DRIVER=		xf86-video-geode
 DRIVER_NAME=	geode_drv
@@ -40,7 +40,7 @@
 CPPFLAGS+=	-DHAVE_CONFIG_H -I${X11SRCDIR.${DRIVER}}/../include
 
 # XXX ugh
-CPPFLAGS+=	-Doff64_t=off_t
+CPPFLAGS+=	-Doff64_t=off_t -Dlseek64=lseek
 
 COPTS.gx_randr.c+=	-Wno-error	# XXX
 COPTS.lx_memory.c+=	-Wno-error	# XXX



CVS commit: xsrc/xfree/xc/lib/Xdmcp

2011-05-18 Thread Izumi Tsutsui
Module Name:xsrc
Committed By:   tsutsui
Date:   Wed May 18 21:00:27 UTC 2011

Modified Files:
xsrc/xfree/xc/lib/Xdmcp: Wraphelp.c

Log Message:
Fix implicit type declarations for -std=gnu99.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 xsrc/xfree/xc/lib/Xdmcp/Wraphelp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: xsrc/xfree/xc/lib/Xdmcp/Wraphelp.c
diff -u xsrc/xfree/xc/lib/Xdmcp/Wraphelp.c:1.2 xsrc/xfree/xc/lib/Xdmcp/Wraphelp.c:1.3
--- xsrc/xfree/xc/lib/Xdmcp/Wraphelp.c:1.2	Fri Mar 18 15:51:29 2005
+++ xsrc/xfree/xc/lib/Xdmcp/Wraphelp.c	Wed May 18 21:00:27 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: Wraphelp.c,v 1.2 2005/03/18 15:51:29 tron Exp $ */
+/* $NetBSD: Wraphelp.c,v 1.3 2011/05/18 21:00:27 tsutsui Exp $ */
 
 /* Export of this software from the United States of America is assumed
  * to require a specific license from the United States Government.
@@ -118,7 +118,7 @@
  * Set up the key schedule from the key.
  */
 
-static
+static void
 setkey(key)
 char *key;
 {
@@ -257,12 +257,13 @@
  * The payoff: encrypt a block.
  */
 
-static
+static void
 encrypt (block, edflag)
 char *block;
+int edflag;
 {
 	int i, ii;
-	register t, j, k;
+	register int t, j, k;
 
 	/*
 	 * First, permute the bits in the input
@@ -347,7 +348,7 @@
 		block[j] = L[FP[j]-1];
 }
 
-static
+static void
 bytes_to_bits (bytes, bits)
 unsigned char   *bytes;
 char	*bits;
@@ -362,7 +363,7 @@
 }
 }
 
-static
+static void
 bits_to_bytes (bits, bytes)
 char	*bits;
 unsigned char   *bytes;



CVS commit: xsrc/external/mit/xf86-video-geode/dist/src

2011-05-18 Thread David Laight
Module Name:xsrc
Committed By:   dsl
Date:   Wed May 18 21:07:09 UTC 2011

Modified Files:
xsrc/external/mit/xf86-video-geode/dist/src: geode_msr.c

Log Message:
Revert previous, -Dlseek64=lseek added to
src/external/mit/xorg/server/drivers/xf86-video-geode/Makefile


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 \
xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c
diff -u xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c:1.2 xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c:1.3
--- xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c:1.2	Wed May 18 20:50:50 2011
+++ xsrc/external/mit/xf86-video-geode/dist/src/geode_msr.c	Wed May 18 21:07:09 2011
@@ -7,8 +7,6 @@
 #include os.h
 #include geode.h
 
-#define lseek64 lseek
-
 static int
 _msr_open(void)
 {



CVS commit: xsrc/xfree/xc/programs

2011-05-18 Thread Izumi Tsutsui
Module Name:xsrc
Committed By:   tsutsui
Date:   Wed May 18 21:29:39 UTC 2011

Modified Files:
xsrc/xfree/xc/programs/xconsole: xconsole.c
xsrc/xfree/xc/programs/xterm: main.c

Log Message:
Include util.h for openpty(3) prototype decl.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 xsrc/xfree/xc/programs/xconsole/xconsole.c
cvs rdiff -u -r1.10 -r1.11 xsrc/xfree/xc/programs/xterm/main.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: xsrc/xfree/xc/programs/xconsole/xconsole.c
diff -u xsrc/xfree/xc/programs/xconsole/xconsole.c:1.3 xsrc/xfree/xc/programs/xconsole/xconsole.c:1.4
--- xsrc/xfree/xc/programs/xconsole/xconsole.c:1.3	Fri Mar 18 14:55:17 2005
+++ xsrc/xfree/xc/programs/xconsole/xconsole.c	Wed May 18 21:29:39 2011
@@ -172,6 +172,9 @@
 #endif
 
 #ifdef USE_PTY
+#if defined(__NetBSD__) || defined(__OpenBSD__) || defined(__FreeBSD__)
+#include util.h
+#endif
 static int get_pty(int *pty, int *tty, char *ttydev, char *ptydev);
 #endif
 #ifdef USE_OSM

Index: xsrc/xfree/xc/programs/xterm/main.c
diff -u xsrc/xfree/xc/programs/xterm/main.c:1.10 xsrc/xfree/xc/programs/xterm/main.c:1.11
--- xsrc/xfree/xc/programs/xterm/main.c:1.10	Fri Mar 18 14:55:18 2005
+++ xsrc/xfree/xc/programs/xterm/main.c	Wed May 18 21:29:39 2011
@@ -376,7 +376,7 @@
 #include local/openpty.h
 #endif /* PUCC_PTYD */
 
-#ifdef __OpenBSD__
+#if defined(__NetBSD__) || defined(__OpenBSD__)
 #include util.h
 #endif
 



CVS commit: xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k

2011-05-18 Thread Izumi Tsutsui
Module Name:xsrc
Committed By:   tsutsui
Date:   Wed May 18 21:51:04 UTC 2011

Modified Files:
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k: x68k.h x68kConfig.c
x68kGraph.c x68kInit.c x68kIo.c x68kKbd.c x68kMouse.c x68kText.c

Log Message:
Dumb fixes to build with -std=gnu99.


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.1 -r1.2 \
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68k.h \
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kIo.c \
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kMouse.c \
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kText.c
cvs rdiff -u -r1.2 -r1.3 \
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kConfig.c \
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kGraph.c \
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kKbd.c
cvs rdiff -u -r1.4 -r1.5 \
xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kInit.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68k.h
diff -u xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68k.h:1.1.1.1 xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68k.h:1.2
--- xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68k.h:1.1.1.1	Wed Jan  7 12:51:46 2004
+++ xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68k.h	Wed May 18 21:51:04 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: x68k.h,v 1.1.1.1 2004/01/07 12:51:46 minoura Exp $ */
+/* $NetBSD: x68k.h,v 1.2 2011/05/18 21:51:04 tsutsui Exp $ */
 /*-
  * Copyright (c) 1996 Yasushi Yamasaki
  * All rights reserved.
@@ -131,4 +131,18 @@
 ((s)-devPrivates[x68kScreenIndex].ptr))
 #define SetupScreen(s) X68kScreenRec *pPriv = GetScreenPrivate(s)
 
+/* x68kFB.c */
+Bool x68kFbCommonOpen(X68kScreenRec *, char *);
+void x68kFbCommonClose(X68kScreenRec *);
+
+/* x68kText.c */
+Bool x68kTextOpen(X68kScreenRec *fb);
+Bool x68kTextInit(int screen, ScreenPtr pScreen, int arg, char *argv[]);
+void x68kTextClose(X68kScreenRec *fb);
+
+/* x68kGraph.c */
+Bool x68kGraphOpen(X68kScreenRec *fb);
+Bool x68kGraphInit(int screen, ScreenPtr pScreen, int arg, char *argv[]);
+void x68kGraphClose(X68kScreenRec *fb);
+
 /* EOF x68k.h */
Index: xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kIo.c
diff -u xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kIo.c:1.1.1.1 xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kIo.c:1.2
--- xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kIo.c:1.1.1.1	Wed Jan  7 12:51:45 2004
+++ xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kIo.c	Wed May 18 21:51:04 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: x68kIo.c,v 1.1.1.1 2004/01/07 12:51:45 minoura Exp $ */
+/* $NetBSD: x68kIo.c,v 1.2 2011/05/18 21:51:04 tsutsui Exp $ */
 /*-
  * Copyright (c) 1996 Yasushi Yamasaki
  * All rights reserved.
@@ -74,6 +74,7 @@
 /
 
 #includex68k.h
+#include mi/mi.h
 
 static void x68kEnqueueEvents();
 extern Firm_event* x68kMouseGetEvents( int fd, int *pNumEvents, Bool *pAgain );
Index: xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kMouse.c
diff -u xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kMouse.c:1.1.1.1 xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kMouse.c:1.2
--- xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kMouse.c:1.1.1.1	Wed Jan  7 12:51:44 2004
+++ xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kMouse.c	Wed May 18 21:51:04 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: x68kMouse.c,v 1.1.1.1 2004/01/07 12:51:44 minoura Exp $ */
+/* $NetBSD: x68kMouse.c,v 1.2 2011/05/18 21:51:04 tsutsui Exp $ */
 /*-
  * Copyright (c) 1996 Yasushi Yamasaki
  * All rights reserved.
@@ -82,6 +82,7 @@
  */
 
 #includex68k.h
+#include mi/mi.h
 
 static Bool x68kCursorOffScreen();
 static void x68kCrossScreen();
Index: xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kText.c
diff -u xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kText.c:1.1.1.1 xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kText.c:1.2
--- xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kText.c:1.1.1.1	Wed Jan  7 12:51:45 2004
+++ xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kText.c	Wed May 18 21:51:04 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: x68kText.c,v 1.1.1.1 2004/01/07 12:51:45 minoura Exp $ */
+/* $NetBSD: x68kText.c,v 1.2 2011/05/18 21:51:04 tsutsui Exp $ */
 /*-
  * Copyright (c) 1996 Yasushi Yamasaki
  * All rights reserved.
@@ -30,6 +30,7 @@
  *---*/
 
 #include x68k.h
+#include mfb.h
 
 /* in x68kConfig.c */
 X68kScreenRec *x68kGetScreenRecByType(int type);

Index: xsrc/xfree/xc/programs/Xserver/hw/netbsd/x68k/x68kConfig.c

CVS commit: othersrc/external/bsd/genraidconf

2011-05-18 Thread Alistair G. Crooks
Module Name:othersrc
Committed By:   agc
Date:   Thu May 19 00:24:22 UTC 2011

Modified Files:
othersrc/external/bsd/genraidconf: genraidconf.sh

Log Message:
one less magic number - make it obvious what the NetBSD partition id is.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 othersrc/external/bsd/genraidconf/genraidconf.sh

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: othersrc/external/bsd/genraidconf/genraidconf.sh
diff -u othersrc/external/bsd/genraidconf/genraidconf.sh:1.4 othersrc/external/bsd/genraidconf/genraidconf.sh:1.5
--- othersrc/external/bsd/genraidconf/genraidconf.sh:1.4	Wed May 18 19:17:21 2011
+++ othersrc/external/bsd/genraidconf/genraidconf.sh	Thu May 19 00:24:22 2011
@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# $NetBSD: genraidconf.sh,v 1.4 2011/05/18 19:17:21 agc Exp $
+# $NetBSD: genraidconf.sh,v 1.5 2011/05/19 00:24:22 agc Exp $
 
 # Copyright (c) 2011 Alistair Crooks a...@netbsd.org
 # All rights reserved.
@@ -49,6 +49,7 @@
 
 doit=
 raiddev=raid0
+netbsdpartid=169
 minraid5=3 # per mrg, no hotswap
 raidlevel=1 # default is RAID1 protection
 spare=0
@@ -155,7 +156,7 @@
 if ${doslabel}; then
 	for d in ${disks}; do
 		secs=$(expr ${sectorc} - 2048)
-		${doit} fdisk -u -a -i -f -3 -s 169/2048/${secs} -b 100/1/${sectorc} -A 2048/2048 ${d}a
+		${doit} fdisk -u -a -i -f -3 -s ${netbsdpartid}/2048/${secs} -b 100/1/${sectorc} -A 2048/2048 ${d}a
 	done
 fi
 



CVS commit: src/sys/arch/amiga/stand/loadkmap

2011-05-18 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu May 19 02:54:58 UTC 2011

Modified Files:
src/sys/arch/amiga/stand/loadkmap: loadkmap.c

Log Message:
include missing headers.


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/amiga/stand/loadkmap/loadkmap.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/amiga/stand/loadkmap/loadkmap.c
diff -u src/sys/arch/amiga/stand/loadkmap/loadkmap.c:1.6 src/sys/arch/amiga/stand/loadkmap/loadkmap.c:1.7
--- src/sys/arch/amiga/stand/loadkmap/loadkmap.c:1.6	Tue Jun 27 06:55:16 2006
+++ src/sys/arch/amiga/stand/loadkmap/loadkmap.c	Wed May 18 22:54:58 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: loadkmap.c,v 1.6 2006/06/27 10:55:16 tsutsui Exp $	*/
+/*	$NetBSD: loadkmap.c,v 1.7 2011/05/19 02:54:58 christos Exp $	*/
 
 #include sys/types.h
 #include sys/stat.h
@@ -7,6 +7,8 @@
 #include ../../dev/kbdmap.h
 #include stdio.h
 #include stdlib.h
+#include unistd.h
+#Include fcntl.h
 
 
 void load_kmap(const char *);



CVS commit: xsrc/external/mit/xf86-video-crime/dist/src

2011-05-18 Thread Christos Zoulas
Module Name:xsrc
Committed By:   christos
Date:   Thu May 19 03:05:19 UTC 2011

Modified Files:
xsrc/external/mit/xf86-video-crime/dist/src: crime_driver.c

Log Message:
include sys/ioctl.h for ioctl()
WTF? Fix pasto calling function from a different driver!?!


To generate a diff of this commit:
cvs rdiff -u -r1.9 -r1.10 \
xsrc/external/mit/xf86-video-crime/dist/src/crime_driver.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: xsrc/external/mit/xf86-video-crime/dist/src/crime_driver.c
diff -u xsrc/external/mit/xf86-video-crime/dist/src/crime_driver.c:1.9 xsrc/external/mit/xf86-video-crime/dist/src/crime_driver.c:1.10
--- xsrc/external/mit/xf86-video-crime/dist/src/crime_driver.c:1.9	Thu Dec 16 23:19:50 2010
+++ xsrc/external/mit/xf86-video-crime/dist/src/crime_driver.c	Wed May 18 23:05:19 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: crime_driver.c,v 1.9 2010/12/17 04:19:50 mrg Exp $ */
+/* $NetBSD: crime_driver.c,v 1.10 2011/05/19 03:05:19 christos Exp $ */
 /*
  * Copyright (c) 2008 Michael Lorenz
  * All rights reserved.
@@ -40,6 +40,7 @@
 #include sys/types.h
 #include sys/time.h
 #include sys/mman.h
+#include sys/ioctl.h
 #include dev/wscons/wsconsio.h
 
 /* all driver need this */
@@ -520,7 +521,7 @@
 	xf86LoaderReqSymLists(fbSymbols, NULL);
 
 	if (xf86LoadSubModule(pScrn, xaa) == NULL) {
-		PnozzFreeRec(pScrn);
+		CrimeFreeRec(pScrn);
 		return FALSE;
 	}
 	xf86LoaderReqSymLists(xaaSymbols, NULL);



CVS commit: src/sys

2011-05-18 Thread Mindaugas Rasiukevicius
Module Name:src
Committed By:   rmind
Date:   Thu May 19 03:11:59 UTC 2011

Modified Files:
src/sys/coda: coda_vnops.c
src/sys/fs/adosfs: advnops.c
src/sys/fs/cd9660: cd9660_node.c
src/sys/fs/efs: efs_vnops.c
src/sys/fs/filecorefs: filecore_node.c
src/sys/fs/hfs: hfs_vnops.c
src/sys/fs/msdosfs: msdosfs_denode.c
src/sys/fs/nilfs: nilfs_vnops.c
src/sys/fs/ntfs: ntfs_vnops.c
src/sys/fs/puffs: puffs_vnops.c
src/sys/fs/smbfs: smbfs_node.c
src/sys/fs/sysvbfs: sysvbfs_vnops.c
src/sys/fs/tmpfs: tmpfs_vnops.c
src/sys/fs/udf: udf_vnops.c
src/sys/kern: vfs_vnode.c
src/sys/nfs: nfs_node.c
src/sys/ufs/ufs: ufs_inode.c

Log Message:
Remove cache_purge(9) calls from reclamation routines in the file systems,
as vclean(9) performs it for us since Lite2 merge.


To generate a diff of this commit:
cvs rdiff -u -r1.78 -r1.79 src/sys/coda/coda_vnops.c
cvs rdiff -u -r1.37 -r1.38 src/sys/fs/adosfs/advnops.c
cvs rdiff -u -r1.27 -r1.28 src/sys/fs/cd9660/cd9660_node.c
cvs rdiff -u -r1.23 -r1.24 src/sys/fs/efs/efs_vnops.c
cvs rdiff -u -r1.22 -r1.23 src/sys/fs/filecorefs/filecore_node.c
cvs rdiff -u -r1.22 -r1.23 src/sys/fs/hfs/hfs_vnops.c
cvs rdiff -u -r1.43 -r1.44 src/sys/fs/msdosfs/msdosfs_denode.c
cvs rdiff -u -r1.10 -r1.11 src/sys/fs/nilfs/nilfs_vnops.c
cvs rdiff -u -r1.48 -r1.49 src/sys/fs/ntfs/ntfs_vnops.c
cvs rdiff -u -r1.151 -r1.152 src/sys/fs/puffs/puffs_vnops.c
cvs rdiff -u -r1.45 -r1.46 src/sys/fs/smbfs/smbfs_node.c
cvs rdiff -u -r1.37 -r1.38 src/sys/fs/sysvbfs/sysvbfs_vnops.c
cvs rdiff -u -r1.80 -r1.81 src/sys/fs/tmpfs/tmpfs_vnops.c
cvs rdiff -u -r1.64 -r1.65 src/sys/fs/udf/udf_vnops.c
cvs rdiff -u -r1.6 -r1.7 src/sys/kern/vfs_vnode.c
cvs rdiff -u -r1.114 -r1.115 src/sys/nfs/nfs_node.c
cvs rdiff -u -r1.84 -r1.85 src/sys/ufs/ufs/ufs_inode.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/coda/coda_vnops.c
diff -u src/sys/coda/coda_vnops.c:1.78 src/sys/coda/coda_vnops.c:1.79
--- src/sys/coda/coda_vnops.c:1.78	Tue Nov 30 10:43:01 2010
+++ src/sys/coda/coda_vnops.c	Thu May 19 03:11:55 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: coda_vnops.c,v 1.78 2010/11/30 10:43:01 dholland Exp $	*/
+/*	$NetBSD: coda_vnops.c,v 1.79 2011/05/19 03:11:55 rmind Exp $	*/
 
 /*
  *
@@ -46,7 +46,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: coda_vnops.c,v 1.78 2010/11/30 10:43:01 dholland Exp $);
+__KERNEL_RCSID(0, $NetBSD: coda_vnops.c,v 1.79 2011/05/19 03:11:55 rmind Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -1735,7 +1735,6 @@
 	}
 #endif
 }
-cache_purge(vp);
 coda_free(VTOC(vp));
 SET_VTOC(vp) = NULL;
 return (0);

Index: src/sys/fs/adosfs/advnops.c
diff -u src/sys/fs/adosfs/advnops.c:1.37 src/sys/fs/adosfs/advnops.c:1.38
--- src/sys/fs/adosfs/advnops.c:1.37	Thu Jun 24 13:03:09 2010
+++ src/sys/fs/adosfs/advnops.c	Thu May 19 03:11:55 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: advnops.c,v 1.37 2010/06/24 13:03:09 hannken Exp $	*/
+/*	$NetBSD: advnops.c,v 1.38 2011/05/19 03:11:55 rmind Exp $	*/
 
 /*
  * Copyright (c) 1994 Christian E. Hopps
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: advnops.c,v 1.37 2010/06/24 13:03:09 hannken Exp $);
+__KERNEL_RCSID(0, $NetBSD: advnops.c,v 1.38 2011/05/19 03:11:55 rmind Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -881,7 +881,6 @@
 	vp = sp-a_vp;
 	ap = VTOA(vp);
 	LIST_REMOVE(ap, link);
-	cache_purge(vp);
 	if (vp-v_type == VDIR  ap-tab)
 		free(ap-tab, M_ANODE);
 	else if (vp-v_type == VLNK  ap-slinkto)

Index: src/sys/fs/cd9660/cd9660_node.c
diff -u src/sys/fs/cd9660/cd9660_node.c:1.27 src/sys/fs/cd9660/cd9660_node.c:1.28
--- src/sys/fs/cd9660/cd9660_node.c:1.27	Wed Jul 21 17:52:09 2010
+++ src/sys/fs/cd9660/cd9660_node.c	Thu May 19 03:11:55 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: cd9660_node.c,v 1.27 2010/07/21 17:52:09 hannken Exp $	*/
+/*	$NetBSD: cd9660_node.c,v 1.28 2011/05/19 03:11:55 rmind Exp $	*/
 
 /*-
  * Copyright (c) 1982, 1986, 1989, 1994
@@ -37,7 +37,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: cd9660_node.c,v 1.27 2010/07/21 17:52:09 hannken Exp $);
+__KERNEL_RCSID(0, $NetBSD: cd9660_node.c,v 1.28 2011/05/19 03:11:55 rmind Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -239,7 +239,6 @@
 	/*
 	 * Purge old data structures associated with the inode.
 	 */
-	cache_purge(vp);
 	if (ip-i_devvp) {
 		vrele(ip-i_devvp);
 		ip-i_devvp = 0;

Index: src/sys/fs/efs/efs_vnops.c
diff -u src/sys/fs/efs/efs_vnops.c:1.23 src/sys/fs/efs/efs_vnops.c:1.24
--- src/sys/fs/efs/efs_vnops.c:1.23	Tue Nov 30 10:43:02 2010
+++ src/sys/fs/efs/efs_vnops.c	Thu May 19 03:11:56 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: efs_vnops.c,v 1.23 2010/11/30 10:43:02 dholland Exp $	*/
+/*	$NetBSD: efs_vnops.c,v 1.24 2011/05/19 03:11:56 rmind Exp $	*/
 
 /*
  * Copyright (c) 2006 Stephen M. Rumble 

CVS commit: src/sys/fs/tmpfs

2011-05-18 Thread Mindaugas Rasiukevicius
Module Name:src
Committed By:   rmind
Date:   Thu May 19 03:13:58 UTC 2011

Modified Files:
src/sys/fs/tmpfs: tmpfs_vnops.c

Log Message:
Add comments, clean up.


To generate a diff of this commit:
cvs rdiff -u -r1.81 -r1.82 src/sys/fs/tmpfs/tmpfs_vnops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/fs/tmpfs/tmpfs_vnops.c
diff -u src/sys/fs/tmpfs/tmpfs_vnops.c:1.81 src/sys/fs/tmpfs/tmpfs_vnops.c:1.82
--- src/sys/fs/tmpfs/tmpfs_vnops.c:1.81	Thu May 19 03:11:58 2011
+++ src/sys/fs/tmpfs/tmpfs_vnops.c	Thu May 19 03:13:58 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: tmpfs_vnops.c,v 1.81 2011/05/19 03:11:58 rmind Exp $	*/
+/*	$NetBSD: tmpfs_vnops.c,v 1.82 2011/05/19 03:13:58 rmind Exp $	*/
 
 /*
  * Copyright (c) 2005, 2006, 2007 The NetBSD Foundation, Inc.
@@ -35,7 +35,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: tmpfs_vnops.c,v 1.81 2011/05/19 03:11:58 rmind Exp $);
+__KERNEL_RCSID(0, $NetBSD: tmpfs_vnops.c,v 1.82 2011/05/19 03:13:58 rmind Exp $);
 
 #include sys/param.h
 #include sys/dirent.h
@@ -115,7 +115,7 @@
 	{ tmpfs_vnodeop_p, tmpfs_vnodeop_entries };
 
 /*
- * tmpfs_lookup: lookup routine.
+ * tmpfs_lookup: path name traversal routine.
  *
  * Arguments: dvp (directory being searched), vpp (result),
  * cnp (component name - path).
@@ -163,25 +163,30 @@
 	 * directory/name couple is already in the cache.
 	 */
 	error = cache_lookup(dvp, vpp, cnp);
-	if (error = 0)
+	if (error = 0) {
+		/* Both cache-hit or an error case. */
 		goto out;
-
-	/* We cannot be requesting the parent directory of the root node. */
-	KASSERT(IMPLIES(dnode-tn_type == VDIR 
-	dnode-tn_spec.tn_dir.tn_parent == dnode,
-	!(cnp-cn_flags  ISDOTDOT)));
+	}
 
 	if (cnp-cn_flags  ISDOTDOT) {
+		struct tmpfs_node *pnode;
+		/*
+		 * Lookup of .. case.
+		 */
+		pnode = dnode-tn_spec.tn_dir.tn_parent;
+		KASSERT(dnode-tn_type == VDIR  pnode != dnode);
 		VOP_UNLOCK(dvp);
 
 		/* Allocate a new vnode on the matching entry. */
-		error = tmpfs_alloc_vp(dvp-v_mount,
-		dnode-tn_spec.tn_dir.tn_parent, vpp);
+		error = tmpfs_alloc_vp(dvp-v_mount, pnode, vpp);
 
 		vn_lock(dvp, LK_EXCLUSIVE | LK_RETRY);
-		goto done;
+		goto out;
 
 	} else if (cnp-cn_namelen == 1  cnp-cn_nameptr[0] == '.') {
+		/*
+		 * Lookup of . case.
+		 */
 		if ((cnp-cn_flags  ISLASTCN) 
 		(cnp-cn_nameiop == RENAME)) {
 			error = EISDIR;
@@ -193,6 +198,9 @@
 		goto done;
 	}
 
+	/*
+	 * Other lookup cases: perform directory scan.
+	 */
 	de = tmpfs_dir_lookup(dnode, cnp);
 	if (de == NULL || de-td_node == TMPFS_NODE_WHITEOUT) {
 		/*
@@ -263,14 +271,12 @@
 	}
 done:
 	/*
-	 * Store the result of this lookup in the cache.  Avoid this if the
-	 * request was for creation, as it does not improve timings on
-	 * emprical tests.
+	 * Cache the result, unless request was for creation (as it does
+	 * not improve the performance).
 	 */
-	if ((cnp-cn_flags  MAKEENTRY)  cnp-cn_nameiop != CREATE 
-	(cnp-cn_flags  ISDOTDOT) == 0)
+	if ((cnp-cn_flags  MAKEENTRY) != 0  cnp-cn_nameiop != CREATE) {
 		cache_enter(dvp, *vpp, cnp);
-
+	}
 out:
 	KASSERT(IFF(error == 0, *vpp != NULL  VOP_ISLOCKED(*vpp)));
 	KASSERT(VOP_ISLOCKED(dvp));
@@ -680,20 +686,20 @@
 	return 0;
 }
 
-/* - */
-
 int
 tmpfs_remove(void *v)
 {
-	struct vnode *dvp = ((struct vop_remove_args *)v)-a_dvp;
-	struct vnode *vp = ((struct vop_remove_args *)v)-a_vp;
-	struct componentname *cnp = (((struct vop_remove_args *)v)-a_cnp);
-
-	int error;
+	struct vop_remove_args /* {
+		struct vnode *a_dvp;
+		struct vnode *a_vp;
+		struct componentname *a_cnp;
+	} */ *ap = v;
+	struct vnode *dvp = ap-a_dvp, *vp = ap-a_vp;
+	struct componentname *cnp = ap-a_cnp;
 	struct tmpfs_dirent *de;
 	struct tmpfs_mount *tmp;
-	struct tmpfs_node *dnode;
-	struct tmpfs_node *node;
+	struct tmpfs_node *dnode, *node;
+	int error;
 
 	KASSERT(VOP_ISLOCKED(dvp));
 	KASSERT(VOP_ISLOCKED(vp));
@@ -703,12 +709,7 @@
 		goto out;
 	}
 
-	dnode = VP_TO_TMPFS_DIR(dvp);
 	node = VP_TO_TMPFS_NODE(vp);
-	tmp = VFS_TO_TMPFS(vp-v_mount);
-	de = tmpfs_dir_lookup(dnode, cnp);
-	KASSERT(de);
-	KASSERT(de-td_node == node);
 
 	/* Files marked as immutable or append-only cannot be deleted. */
 	if (node-tn_flags  (IMMUTABLE | APPEND)) {
@@ -716,17 +717,22 @@
 		goto out;
 	}
 
-	/* Remove the entry from the directory; as it is a file, we do not
-	 * have to change the number of hard links of the directory. */
+	/*
+	 * Lookup and remove the entry from the directory.  Note that since
+	 * it is a file, we do not need to change the number of hard links.
+	 */
+	dnode = VP_TO_TMPFS_DIR(dvp);
+	de = tmpfs_dir_lookup(dnode, cnp);
+	KASSERT(de  de-td_node == node);
 	tmpfs_dir_detach(dvp, de);
 
-	/* Free the directory entry we just deleted.  Note that the node
-	 * referred by it will not be removed until the vnode is really
-	 * reclaimed. */
+	/*
+	 

CVS commit: src/gnu/dist/gcc4/gcc/config/m68k

2011-05-18 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu May 19 03:18:01 UTC 2011

Modified Files:
src/gnu/dist/gcc4/gcc/config/m68k: fpgnulib.c

Log Message:
Add missing prototype for __cmpdf2


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.1 -r1.2 src/gnu/dist/gcc4/gcc/config/m68k/fpgnulib.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/gnu/dist/gcc4/gcc/config/m68k/fpgnulib.c
diff -u src/gnu/dist/gcc4/gcc/config/m68k/fpgnulib.c:1.1.1.1 src/gnu/dist/gcc4/gcc/config/m68k/fpgnulib.c:1.2
--- src/gnu/dist/gcc4/gcc/config/m68k/fpgnulib.c:1.1.1.1	Thu Apr 20 05:45:48 2006
+++ src/gnu/dist/gcc4/gcc/config/m68k/fpgnulib.c	Wed May 18 23:18:01 2011
@@ -298,6 +298,7 @@
 float __truncdfsf2 (double);
 long __fixdfsi (double);
 long __fixsfsi (float);
+int __cmpdf2 (double, double);
 
 /* convert double to long double */
 long double



CVS commit: src/sys/fs/tmpfs

2011-05-18 Thread Mindaugas Rasiukevicius
Module Name:src
Committed By:   rmind
Date:   Thu May 19 03:21:24 UTC 2011

Modified Files:
src/sys/fs/tmpfs: tmpfs.h tmpfs_mem.c tmpfs_vfsops.c

Log Message:
- tmpfs: do not create dirent/node pools per-mount, there is no need to.
- tmpfs_mount: fix a leak of mount structures in error path.


To generate a diff of this commit:
cvs rdiff -u -r1.39 -r1.40 src/sys/fs/tmpfs/tmpfs.h
cvs rdiff -u -r1.2 -r1.3 src/sys/fs/tmpfs/tmpfs_mem.c
cvs rdiff -u -r1.47 -r1.48 src/sys/fs/tmpfs/tmpfs_vfsops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/fs/tmpfs/tmpfs.h
diff -u src/sys/fs/tmpfs/tmpfs.h:1.39 src/sys/fs/tmpfs/tmpfs.h:1.40
--- src/sys/fs/tmpfs/tmpfs.h:1.39	Thu Jan 13 13:35:11 2011
+++ src/sys/fs/tmpfs/tmpfs.h	Thu May 19 03:21:23 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: tmpfs.h,v 1.39 2011/01/13 13:35:11 pooka Exp $	*/
+/*	$NetBSD: tmpfs.h,v 1.40 2011/05/19 03:21:23 rmind Exp $	*/
 
 /*
  * Copyright (c) 2005, 2006, 2007 The NetBSD Foundation, Inc.
@@ -298,11 +298,6 @@
 	/* Node list. */
 	kmutex_t		tm_lock;
 	struct tmpfs_node_list	tm_nodes;
-
-	char			tm_dwchan[32];
-	struct pool		tm_dirent_pool;
-	char			tm_nwchan[32];
-	struct pool		tm_node_pool;
 };
 
 /* - */

Index: src/sys/fs/tmpfs/tmpfs_mem.c
diff -u src/sys/fs/tmpfs/tmpfs_mem.c:1.2 src/sys/fs/tmpfs/tmpfs_mem.c:1.3
--- src/sys/fs/tmpfs/tmpfs_mem.c:1.2	Mon Jun 28 19:32:43 2010
+++ src/sys/fs/tmpfs/tmpfs_mem.c	Thu May 19 03:21:23 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: tmpfs_mem.c,v 1.2 2010/06/28 19:32:43 rmind Exp $	*/
+/*	$NetBSD: tmpfs_mem.c,v 1.3 2011/05/19 03:21:23 rmind Exp $	*/
 
 /*
  * Copyright (c) 2010 The NetBSD Foundation, Inc.
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: tmpfs_mem.c,v 1.2 2010/06/28 19:32:43 rmind Exp $);
+__KERNEL_RCSID(0, $NetBSD: tmpfs_mem.c,v 1.3 2011/05/19 03:21:23 rmind Exp $);
 
 #include sys/param.h
 #include sys/atomic.h
@@ -42,18 +42,13 @@
 
 #include fs/tmpfs/tmpfs.h
 
+extern struct pool	tmpfs_dirent_pool;
+extern struct pool	tmpfs_node_pool;
+
 void
 tmpfs_mntmem_init(struct tmpfs_mount *mp, uint64_t memlimit)
 {
 
-	sprintf(mp-tm_dwchan, tmpfs_dirent_%p, mp);
-	pool_init(mp-tm_dirent_pool, sizeof(struct tmpfs_dirent), 0, 0, 0,
-	mp-tm_dwchan, pool_allocator_nointr, IPL_NONE);
-
-	sprintf(mp-tm_nwchan, tmpfs_node_%p, mp);
-	pool_init(mp-tm_node_pool, sizeof(struct tmpfs_node), 0, 0, 0,
-	mp-tm_dwchan, pool_allocator_nointr, IPL_NONE);
-
 	mutex_init(mp-tm_acc_lock, MUTEX_DEFAULT, IPL_NONE);
 	mp-tm_mem_limit = memlimit;
 	mp-tm_bytes_used = 0;
@@ -65,8 +60,6 @@
 
 	KASSERT(mp-tm_bytes_used == 0);
 	mutex_destroy(mp-tm_acc_lock);
-	pool_destroy(mp-tm_dirent_pool);
-	pool_destroy(mp-tm_node_pool);
 }
 
 /*
@@ -153,7 +146,7 @@
 	if (!tmpfs_mem_incr(mp, sizeof(struct tmpfs_dirent))) {
 		return NULL;
 	}
-	return pool_get(mp-tm_dirent_pool, PR_WAITOK);
+	return pool_get(tmpfs_dirent_pool, PR_WAITOK);
 }
 
 void
@@ -161,7 +154,7 @@
 {
 
 	tmpfs_mem_decr(mp, sizeof(struct tmpfs_dirent));
-	pool_put(mp-tm_dirent_pool, de);
+	pool_put(tmpfs_dirent_pool, de);
 }
 
 struct tmpfs_node *
@@ -171,7 +164,7 @@
 	if (!tmpfs_mem_incr(mp, sizeof(struct tmpfs_node))) {
 		return NULL;
 	}
-	return pool_get(mp-tm_node_pool, PR_WAITOK);
+	return pool_get(tmpfs_node_pool, PR_WAITOK);
 }
 
 void
@@ -179,7 +172,7 @@
 {
 
 	tmpfs_mem_decr(mp, sizeof(struct tmpfs_node));
-	pool_put(mp-tm_node_pool, tn);
+	pool_put(tmpfs_node_pool, tn);
 }
 
 /*

Index: src/sys/fs/tmpfs/tmpfs_vfsops.c
diff -u src/sys/fs/tmpfs/tmpfs_vfsops.c:1.47 src/sys/fs/tmpfs/tmpfs_vfsops.c:1.48
--- src/sys/fs/tmpfs/tmpfs_vfsops.c:1.47	Sat Apr  2 14:24:53 2011
+++ src/sys/fs/tmpfs/tmpfs_vfsops.c	Thu May 19 03:21:23 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: tmpfs_vfsops.c,v 1.47 2011/04/02 14:24:53 hannken Exp $	*/
+/*	$NetBSD: tmpfs_vfsops.c,v 1.48 2011/05/19 03:21:23 rmind Exp $	*/
 
 /*
  * Copyright (c) 2005, 2006, 2007 The NetBSD Foundation, Inc.
@@ -42,7 +42,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: tmpfs_vfsops.c,v 1.47 2011/04/02 14:24:53 hannken Exp $);
+__KERNEL_RCSID(0, $NetBSD: tmpfs_vfsops.c,v 1.48 2011/05/19 03:21:23 rmind Exp $);
 
 #include sys/param.h
 #include sys/types.h
@@ -60,7 +60,8 @@
 
 MODULE(MODULE_CLASS_VFS, tmpfs, NULL);
 
-/* - */
+struct pool	tmpfs_dirent_pool;
+struct pool	tmpfs_node_pool;
 
 static int	tmpfs_mount(struct mount *, const char *, void *, size_t *);
 static int	tmpfs_start(struct mount *, int);
@@ -76,7 +77,23 @@
 static int	tmpfs_snapshot(struct mount *, struct vnode *,
 		struct timespec *);
 
-/* - */
+static void
+tmpfs_init(void)
+{
+
+	pool_init(tmpfs_dirent_pool, sizeof(struct tmpfs_dirent), 0, 0, 0,
+	tmpfs_dirent, pool_allocator_nointr, IPL_NONE);
+	

CVS commit: src/sys/arch/x68k/usr.bin/loadfont

2011-05-18 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu May 19 03:22:27 UTC 2011

Modified Files:
src/sys/arch/x68k/usr.bin/loadfont: loadfont.c

Log Message:
fix header includes


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/x68k/usr.bin/loadfont/loadfont.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x68k/usr.bin/loadfont/loadfont.c
diff -u src/sys/arch/x68k/usr.bin/loadfont/loadfont.c:1.7 src/sys/arch/x68k/usr.bin/loadfont/loadfont.c:1.8
--- src/sys/arch/x68k/usr.bin/loadfont/loadfont.c:1.7	Thu Aug  3 22:30:00 2006
+++ src/sys/arch/x68k/usr.bin/loadfont/loadfont.c	Wed May 18 23:22:27 2011
@@ -3,15 +3,16 @@
  * from: amiga/stand/loadkmap/loadkmap.c
  * Copyright 1993 by Masaru Oki
  *
- *	$NetBSD: loadfont.c,v 1.7 2006/08/04 02:30:00 mhitch Exp $
+ *	$NetBSD: loadfont.c,v 1.8 2011/05/19 03:22:27 christos Exp $
  */
 
 #include sys/cdefs.h
-__RCSID($NetBSD: loadfont.c,v 1.7 2006/08/04 02:30:00 mhitch Exp $);
+__RCSID($NetBSD: loadfont.c,v 1.8 2011/05/19 03:22:27 christos Exp $);
 
 #include stdio.h
 #include stdlib.h
-#include sys/file.h
+#include fcntl.h
+#include unistd.h
 #include sys/ioctl.h
 #define ITEKANJI 1 /* XXX */
 #include machine/iteioctl.h



CVS commit: src/sys/kern

2011-05-18 Thread Mindaugas Rasiukevicius
Module Name:src
Committed By:   rmind
Date:   Thu May 19 03:26:06 UTC 2011

Modified Files:
src/sys/kern: vfs_vnode.c

Log Message:
Add some general description of vnode life-cycle.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sys/kern/vfs_vnode.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/vfs_vnode.c
diff -u src/sys/kern/vfs_vnode.c:1.7 src/sys/kern/vfs_vnode.c:1.8
--- src/sys/kern/vfs_vnode.c:1.7	Thu May 19 03:11:55 2011
+++ src/sys/kern/vfs_vnode.c	Thu May 19 03:26:06 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: vfs_vnode.c,v 1.7 2011/05/19 03:11:55 rmind Exp $	*/
+/*	$NetBSD: vfs_vnode.c,v 1.8 2011/05/19 03:26:06 rmind Exp $	*/
 
 /*-
  * Copyright (c) 1997-2011 The NetBSD Foundation, Inc.
@@ -67,31 +67,61 @@
  */
 
 /*
- * Note on v_usecount and locking:
+ * The vnode cache subsystem.
  *
- * At nearly all points it is known that v_usecount could be zero, the
- * vnode interlock will be held.
+ * Life-cycle
  *
- * To change v_usecount away from zero, the interlock must be held.  To
- * change from a non-zero value to zero, again the interlock must be
- * held.
- *
- * There's a flag bit, VC_XLOCK, embedded in v_usecount.
- * To raise v_usecount, if the VC_XLOCK bit is set in it, the interlock
- * must be held.
- * To modify the VC_XLOCK bit, the interlock must be held.
- * We always keep the usecount (v_usecount  VC_MASK) non-zero while the
- * VC_XLOCK bit is set.
- *
- * Unless the VC_XLOCK bit is set, changing the usecount from a non-zero
- * value to a non-zero value can safely be done using atomic operations,
- * without the interlock held.
- * Even if the VC_XLOCK bit is set, decreasing the usecount to a non-zero
- * value can be done using atomic operations, without the interlock held.
+ *	Normally, there are two points where new vnodes are created:
+ *	VOP_CREATE(9) and VOP_LOOKUP(9).  The life-cycle of a vnode
+ *	starts in one of the following ways:
+ *
+ *	- Allocation, via getnewvnode(9) and/or vnalloc(9).
+ *	- Recycle from a free list, via getnewvnode(9) - getcleanvnode(9).
+ *	- Reclamation of inactive vnode, via vget(9).
+ *
+ *	The life-cycle ends when the last reference is dropped, usually
+ *	in VOP_REMOVE(9).  In such case, VOP_INACTIVE(9) is called to inform
+ *	the file system that vnode is inactive.  Via this call, file system
+ *	indicates whether vnode should be recycled (usually, count of links
+ *	is checked i.e. whether file was removed).
+ *
+ *	Depending on indication, vnode can be put into a free list (cache),
+ *	or cleaned via vclean(9), which calls VOP_RECLAIM(9) to disassociate
+ *	underlying file system from the vnode, and finally destroyed.
+ *
+ * Reference counting
+ *
+ *	Vnode is considered active, if reference count (vnode_t::v_usecount)
+ *	is non-zero.  It is maintained using: vref(9) and vrele(9), as well
+ *	as vput(9), routines.  Common points holding references are e.g.
+ *	file openings, current working directory, mount points, etc.  
+ *
+ * Note on v_usecount and its locking
+ *
+ *	At nearly all points it is known that v_usecount could be zero,
+ *	the vnode_t::v_interlock will be held.  To change v_usecount away
+ *	from zero, the interlock must be held.  To change from a non-zero
+ *	value to zero, again the interlock must be held.
+ *
+ *	There is a flag bit, VC_XLOCK, embedded in v_usecount.  To raise
+ *	v_usecount, if the VC_XLOCK bit is set in it, the interlock must
+ *	be held.  To modify the VC_XLOCK bit, the interlock must be held.
+ *	We always keep the usecount (v_usecount  VC_MASK) non-zero while
+ *	the VC_XLOCK bit is set.
+ *
+ *	Unless the VC_XLOCK bit is set, changing the usecount from a non-zero
+ *	value to a non-zero value can safely be done using atomic operations,
+ *	without the interlock held.
+ *
+ *	Even if the VC_XLOCK bit is set, decreasing the usecount to a non-zero
+ *	value can be done using atomic operations, without the interlock held.
+ *
+ *	Note: if VI_CLEAN is set, vnode_t::v_interlock will be released while
+ *	mntvnode_lock is still held.
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: vfs_vnode.c,v 1.7 2011/05/19 03:11:55 rmind Exp $);
+__KERNEL_RCSID(0, $NetBSD: vfs_vnode.c,v 1.8 2011/05/19 03:26:06 rmind Exp $);
 
 #include sys/param.h
 #include sys/kernel.h



CVS commit: src/sys/arch/sparc64/dev

2011-05-18 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Thu May 19 04:43:45 UTC 2011

Modified Files:
src/sys/arch/sparc64/dev: ffb.c

Log Message:
remove obsolete comment - putchar() does in fact use the blitter now


To generate a diff of this commit:
cvs rdiff -u -r1.41 -r1.42 src/sys/arch/sparc64/dev/ffb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/dev/ffb.c
diff -u src/sys/arch/sparc64/dev/ffb.c:1.41 src/sys/arch/sparc64/dev/ffb.c:1.42
--- src/sys/arch/sparc64/dev/ffb.c:1.41	Mon May  9 09:06:28 2011
+++ src/sys/arch/sparc64/dev/ffb.c	Thu May 19 04:43:45 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: ffb.c,v 1.41 2011/05/09 09:06:28 jdc Exp $	*/
+/*	$NetBSD: ffb.c,v 1.42 2011/05/19 04:43:45 macallan Exp $	*/
 /*	$OpenBSD: creator.c,v 1.20 2002/07/30 19:48:15 jason Exp $	*/
 
 /*
@@ -33,7 +33,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ffb.c,v 1.41 2011/05/09 09:06:28 jdc Exp $);
+__KERNEL_RCSID(0, $NetBSD: ffb.c,v 1.42 2011/05/19 04:43:45 macallan Exp $);
 
 #include sys/types.h
 #include sys/param.h
@@ -991,11 +991,6 @@
 	struct wsdisplay_font *font = PICK_FONT(ri, c);
 	struct ffb_softc *sc = scr-scr_cookie;
 	
-	/*
-	 * font operations don't use the blitter so we have to wait here
-	 * in case we were scrolling
-	 */
-	
 	if (sc-sc_mode == WSDISPLAYIO_MODE_EMUL) {
 		void *data;
 		uint32_t fg, bg;



CVS commit: src/distrib/notes/common

2011-05-18 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu May 19 05:13:10 UTC 2011

Modified Files:
src/distrib/notes/common: main

Log Message:
Add my name to the list.


To generate a diff of this commit:
cvs rdiff -u -r1.476 -r1.477 src/distrib/notes/common/main

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/notes/common/main
diff -u src/distrib/notes/common/main:1.476 src/distrib/notes/common/main:1.477
--- src/distrib/notes/common/main:1.476	Sat May  7 11:12:48 2011
+++ src/distrib/notes/common/main	Thu May 19 05:13:09 2011
@@ -1,4 +1,4 @@
-.\	$NetBSD: main,v 1.476 2011/05/07 11:12:48 cheusov Exp $
+.\	$NetBSD: main,v 1.477 2011/05/19 05:13:09 riastradh Exp $
 .\
 .\ Copyright (c) 1999-2008 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -1113,6 +1113,7 @@
 .It Ta Robert Byrnes Ta Mt byr...@netbsd.org
 .It Ta Pavel Cahyna Ta Mt pa...@netbsd.org
 .It Ta D'Arcy J.M. Cain Ta Mt da...@netbsd.org
+.It Ta Taylor R. Campbell Ta Mt riastr...@netbsd.org
 .It Ta Daniel Carosone Ta Mt d...@netbsd.org
 .It Ta Dave Carrel Ta Mt car...@netbsd.org
 .It Ta James Chacon Ta Mt j...@netbsd.org
Index: src/lib/libperfuse/ops.c
diff -u src/lib/libperfuse/ops.c:1.26 src/lib/libperfuse/ops.c:1.27
--- src/lib/libperfuse/ops.c:1.26	Wed May 11 14:52:48 2011
+++ src/lib/libperfuse/ops.c	Wed May 18 15:28:12 2011
@@ -1,4 +1,4 @@
-/*  $NetBSD: ops.c,v 1.26 2011/05/11 14:52:48 jakllsch Exp $ */
+/*  $NetBSD: ops.c,v 1.27 2011/05/18 15:28:12 manu Exp $ */
 
 /*-
  *  Copyright (c) 2010-2011 Emmanuel Dreyfus. All rights reserved.
@@ -262,7 +262,7 @@
 	vap-va_nlink = fa-nlink;
 	vap-va_uid = fa-uid;
 	vap-va_gid = fa-gid;
-	vap-va_fsid = ps-ps_fsid;
+	vap-va_fsid = (long)ps-ps_fsid;
 	vap-va_fileid = fa-ino;
 	vap-va_size = fa-size;
 	vap-va_blocksize = fa-blksize;
@@ -996,7 +996,10 @@
 	case NAMEI_DELETE: /* FALLTHROUGH */
 	case NAMEI_RENAME: /* FALLTHROUGH */
 	case NAMEI_CREATE:
-		mode = PUFFS_VEXEC|PUFFS_VWRITE;
+		if (pcn-pcn_flags  NAMEI_ISLASTCN)
+			mode = PUFFS_VEXEC|PUFFS_VWRITE;
+		else
+			mode = PUFFS_VEXEC;
 		break;
 	case NAMEI_LOOKUP: /* FALLTHROUGH */
 	default:
@@ -1271,7 +1274,7 @@
 
 	/*
 	 * libfuse docs says
 	 * - O_CREAT should never be set.
 	 * - O_TRUNC may be used if mount option atomic_o_trunc is used XXX
 	 *
 	 * O_APPEND makes no sense since FUSE always sends
@@ -1279,7 +1282,7 @@
 	 * filesystem uses pwrite(), O_APPEND would cause
 	 * the offset to be ignored and cause file corruption.
 	 */
-	mode = ~(O_CREAT|O_APPEND);
+	mode = ~(O_CREAT|O_EXCL|O_APPEND);
 
 	/*
 	 * Do not open twice, and do not reopen for reading
@@ -1271,7 +1274,7 @@
 	/*
 	 * libfuse docs says
-	 * - O_CREAT should never be set.
+	 * - O_CREAT and O_EXCL should never be set.
 	 * - O_TRUNC may be used if mount option atomic_o_trunc is used XXX
 	 *



CVS commit: src/sys/rump/librump/rumpkern

2011-05-18 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Wed May 18 15:57:15 UTC 2011

Modified Files:
src/sys/rump/librump/rumpkern: signals.c

Log Message:
add a hacky version of sigsuspendsetup() to satisfy link requirements.


To generate a diff of this commit:
cvs rdiff -u -r1.8 -r1.9 src/sys/rump/librump/rumpkern/signals.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
